"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from typing_extensions import TypedDict


class MessageResponseTypedDict(TypedDict):
    message: str


class MessageResponse(BaseModel):
    message: str
